# Default Configuration for Microsoft Build Engine

!include <win32.mak>

CC = cl
LINKER = link
AR = lib
CP = copy
MV = move
RM = del

CFLAGS = $(cdebug) $(cflags) $(cvarsmt) -MT /openmp /w -I ..\include 
LDFLAGS = $(ldebug) $(conlflags) $(conlibsmt)


# For Intel Compiler

ICC = icl
IFC = ifort
ICCFLAGS = /O3 /MT /Qopenmp /Qopenmp-lib:compat /Qansi_alias -DUSE_FORTRAN -DUSE_SAAMG
IFCFLAGS = /O3 /MT /Qopenmp /Qopenmp-lib:compat /Qansi_alias


# For MPI

MPIFLAGS = -DUSE_MPI
CMPILIB = mpi.lib 
FMPILIB = fmpich2.lib


all: libs exes_test exes_etest exes_spmvtest
	$(CP) test1.exe lsolve.exe
	$(CP) etest5.exe esolve.exe

libs: objs_esolver objs_fortran objs_matrix objs_matvec objs_precision objs_precon objs_solver objs_system objs_vector
	$(AR) *.obj /out:lis.lib

objs_esolver: ..\src\esolver\*.obj 
objs_fortran: ..\src\fortran\*.obj 
objs_matrix: ..\src\matrix\*.obj 
objs_matvec: ..\src\matvec\*.obj 
objs_precision: ..\src\precision\*.obj 
objs_precon: ..\src\precon\*.obj 
objs_solver: ..\src\solver\*.obj 
objs_system: ..\src\system\*.obj 
objs_vector: ..\src\vector\*.obj
objs_saamg: ..\src\fortran\amg\*.obj

exes_test: test1.exe test2.exe test3.exe test4.exe test5.exe test6.exe
exes_etest: etest1.exe etest2.exe etest3.exe etest4.exe etest5.exe etest6.exe
exes_spmvtest: spmvtest1.exe spmvtest2.exe spmvtest3.exe spmvtest4.exe spmvtest5.exe
exes_testf: test1f.exe test4f.exe
exes_etestf: etest1f.exe etest4f.exe

test1.exe: ..\test\$*.obj
test2.exe: ..\test\$*.obj
test3.exe: ..\test\$*.obj
test4.exe: ..\test\$*.obj
test5.exe: ..\test\$*.obj
test6.exe: ..\test\$*.obj
etest1.exe: ..\test\$*.obj
etest2.exe: ..\test\$*.obj
etest3.exe: ..\test\$*.obj
etest4.exe: ..\test\$*.obj
etest5.exe: ..\test\$*.obj
etest6.exe: ..\test\$*.obj
spmvtest1.exe: ..\test\$*.obj
spmvtest2.exe: ..\test\$*.obj
spmvtest3.exe: ..\test\$*.obj
spmvtest4.exe: ..\test\$*.obj
spmvtest5.exe: ..\test\$*.obj
test1f.exe: ..\test\$*.obj
test4f.exe: ..\test\$*.obj
etest1f.exe: ..\test\$*.obj
etest4f.exe: ..\test\$*.obj

.c.obj:
	$(CC) $(CFLAGS) $*.c

.F.obj:
	$(IFC) $(IFCFLAGS) $*.F

.F90.obj:
	$(IFC) $(IFCFLAGS) $*.F90

.obj.exe:
	$(LINKER) $(LDFLAGS) $*.obj lis.lib

clean:
	$(RM) *.obj *.pdb

cleanall: 
	$(RM) *.lib *.exe *.obj *.pdb
